package com.dcsoft.system.consume.mapper;



import com.dcsoft.system.consume.domain.ConsumeGroup;

import java.util.List;

/**
 * 考勤组Mapper接口
 *
 * @author dcsoft
 * @date 2023-01-05
 */
public interface ConsumeGroupMapper
{
    /**
     * 查询考勤组
     *
     * @param groupId 考勤组主键
     * @return 考勤组
     */
    public ConsumeGroup selectConsumeGroupByGroupId(Long groupId);

    /**
     * 查询考勤组列表
     *
     * @param consumeGroup 考勤组
     * @return 考勤组集合
     */
    public List<ConsumeGroup> selectConsumeGroupList(ConsumeGroup consumeGroup);

    /**
     * 新增考勤组
     *
     * @param consumeGroup 考勤组
     * @return 结果
     */
    public int insertConsumeGroup(ConsumeGroup consumeGroup);

    /**
     * 修改考勤组
     *
     * @param consumeGroup 考勤组
     * @return 结果
     */
    public int updateConsumeGroup(ConsumeGroup consumeGroup);

    /**
     * 删除考勤组
     *
     * @param groupId 考勤组主键
     * @return 结果
     */
    public int deleteConsumeGroupByGroupId(Long groupId);

    /**
     * 批量删除考勤组
     *
     * @param groupIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteConsumeGroupByGroupIds(Long[] groupIds);
}
